@@ -291,7 +291,7 @@ class UnicornView(TemplateView):
         pass
 
     @timed
-    def render(self, init_js=False) -> str:
+    def render(self, init_js=False, extra_context=None) -> str:
         """
         Renders a UnicornView component with the public properties available. Delegates to a
         UnicornTemplateResponse to actually render a response.
@@ -300,6 +300,9 @@ class UnicornView(TemplateView):
             param init_js: Whether or not to include the Javascript required to initialize the component.
         """
 
+        if extra_context is not None:
+            self.extra_context = extra_context
+
         response = self.render_to_response(
             context=self.get_context_data(),
             component=self,
@@ -335,7 +338,7 @@ class UnicornView(TemplateView):
         attributes = self._attributes()
         frontend_context_variables.update(attributes)
 
-        exclude_field_attributes = ()
+        exclude_field_attributes = []
 
         # Remove any field in `javascript_exclude` from `frontend_context_variables`
         if hasattr(self, "Meta") and hasattr(self.Meta, "javascript_exclude"):
@@ -374,7 +377,7 @@ class UnicornView(TemplateView):
 
         encoded_frontend_context_variables = serializer.dumps(
             frontend_context_variables,
-            exclude_field_attributes=exclude_field_attributes,
+            exclude_field_attributes=tuple(exclude_field_attributes),
         )
 
         return encoded_frontend_context_variables
